@@ -7,7 +7,7 @@ use Carp;
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(is_holiday holidays);
-our $VERSION   = '0.06';
+our $VERSION   = '0.07';
 
 use warnings;
 use strict;
@@ -986,6 +986,12 @@ sub _compute_wa_queens_bday { # monday closest to 30 september???  Formula unkno
 	} elsif ($year == 2010) {
 		$day = 27;
 		$month = 8;
+	} elsif ($year == 2011) {
+		$day = 3;
+		$month = 9;
+	} elsif ($year == 2012) {
+		$day = 1;
+		$month = 9;
 	} else {
 		croak("Don't know how to calculate Queen's Birthday in WA for this year\n");
 	}
